# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Snappy Ecosystem Tests
# Copyright (C) 2017 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""snapd data"""
SNAPD_CONTAINER_NAME = 'snapd'

CONTAINER_HOME = '/root'
DIRECTORY_CLONE = '{}/src/github.com/snapcore/snapd'.format(CONTAINER_HOME)
DOMAIN_PING = 'ubuntu.com'
ENV_STORE_API_ROOT = 'UBUNTU_STORE_API_ROOT_URL'
ENV_STORE_SEARCH_ROOT = 'UBUNTU_STORE_SEARCH_ROOT_URL'
ENV_STORE_UPLOAD_ROOT = 'UBUNTU_STORE_UPLOAD_ROOT_URL'
ENV_SSO_API_ROOT = 'UBUNTU_SSO_API_ROOT_URL'
PACKAGES_SNAPD = ['snapd', 'snap-confine', 'ubuntu-core-launcher']
COMMAND_REMOVE_SNAPD = 'apt purge -y {}'.format(' '.join(PACKAGES_SNAPD))
COMMAND_APT_BUILD_DEP = 'apt build-dep -y ./'
COMMAND_APT_INSTALL = 'apt install -y {}'
COMMAND_APT_INSTALL_STAGING_DEBS = COMMAND_APT_INSTALL.format(
    ' '.join(['../{}*.deb'.format(pkg) for pkg in PACKAGES_SNAPD]))
COMMAND_APT_UPDATE = 'apt update'
COMMAND_APT_UPGRADE = 'apt dist-upgrade -y'
COMMAND_BUILD_SNAPD = 'DEB_BUILD_OPTIONS="nocheck testkeys" ' \
                      'dpkg-buildpackage -tc -b'
COMMAND_EXPORT_STAGING_STORE_VAR = 'echo SNAPPY_USE_STAGING_STORE=1 >> ' \
                                   '/etc/environment'
COMMAND_GET_GOVENDOR = 'go get -v github.com/kardianos/govendor'
COMMAND_GIT_CLONE = 'git clone {} {}'
COMMAND_GOVENDOR_SYNC = 'govendor sync'
REPOSITORY_GIT = 'https://github.com/snapcore/snapd'
URL_API_ROOT = 'https://myapps.developer.staging.ubuntu.com/dev/api/'
URL_SEARCH_ROOT = 'https://search.apps.staging.ubuntu.com/'
URL_UPLOAD_ROOT = 'https://upload.apps.staging.ubuntu.com/'
URL_SSO_API_ROOT = 'https://login.staging.ubuntu.com/api/v2/'

CONTAINER_SETUP = [
    COMMAND_REMOVE_SNAPD,
    COMMAND_APT_UPDATE,
    # Hold open-iscsi which is causing apt upgrade errors while running
    # inside container.
    'apt-mark hold open-iscsi',
    COMMAND_APT_UPGRADE,
    # Needed for snaps to work inside a lxd container
    #  ref: https://stgraber.org/2016/12/07/running-snaps-in-lxd-containers/
    COMMAND_APT_INSTALL.format('squashfuse'),
    COMMAND_GIT_CLONE.format(REPOSITORY_GIT, DIRECTORY_CLONE),
    {'command': COMMAND_APT_BUILD_DEP, 'cwd': DIRECTORY_CLONE},
    {'command': COMMAND_GET_GOVENDOR, 'cwd': DIRECTORY_CLONE},
    {'command': COMMAND_GOVENDOR_SYNC, 'cwd': DIRECTORY_CLONE},
    {'command': COMMAND_BUILD_SNAPD, 'cwd': DIRECTORY_CLONE},
    COMMAND_EXPORT_STAGING_STORE_VAR,
    {'command': COMMAND_APT_INSTALL_STAGING_DEBS, 'cwd': DIRECTORY_CLONE}
]

SNAPCRAFT_STAGING_VARIABLES = {
    ENV_STORE_API_ROOT: URL_API_ROOT,
    ENV_STORE_SEARCH_ROOT: URL_SEARCH_ROOT,
    ENV_STORE_UPLOAD_ROOT: URL_UPLOAD_ROOT,
    ENV_SSO_API_ROOT: URL_SSO_API_ROOT,
}

SNAPD_STAGING_VARIABLES = {
    'SNAPPY_USE_STAGING_STORE': '1'
}

STAGING_VARIABLES = dict(
    SNAPCRAFT_STAGING_VARIABLES, **SNAPD_STAGING_VARIABLES)

CONTAINER_ENV_VARS = {
    'GOPATH': CONTAINER_HOME,
}

DEFAULT_CONTAINER_CONFIG = {
    "name": "snapd",
    "source": {
        "type": "image",
        "mode": "pull",
        "server": "https://cloud-images.ubuntu.com/releases",
        "protocol": "simplestreams",
        "fingerprint": "16.04"
    }
}
