# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Snappy Ecosystem Tests
# Copyright (C) 2017 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#


"""General fixtures related to the store and the tests environment"""

import os

import fixtures

from snappy_ecosystem_tests.commons.config import CONFIG_STACK
from snappy_ecosystem_tests.utils.storeconfig import get_current_store


class TempCWD(fixtures.TempDir):
    """Create a temporary directory an cd into it for the test duration."""

    def setUp(self):
        super().setUp()
        self.addCleanup(os.chdir, os.getcwd())
        os.chdir(self.path)


class CleanEnvironment(fixtures.Fixture):
    """Clean all env variables and restore the original values as
    clean up process"""

    def setUp(self):
        super().setUp()
        current_environment = os.environ.copy()
        os.environ = {}
        self.addCleanup(os.environ.update, current_environment)


class SetStoreEnvironmentVariables(fixtures.Fixture):
    """Configure the env variables for using staging urls"""

    def __init__(self, store):
        self.store = store

    def setUp(self):
        super().setUp()
        urls = CONFIG_STACK.get_section('%s_urls' % self.store)

        self.useFixture(fixtures.EnvironmentVariable(
            'UBUNTU_STORE_API_ROOT_URL',
            urls.get('root_api')))
        self.useFixture(fixtures.EnvironmentVariable(
            'UBUNTU_STORE_UPLOAD_ROOT_URL',
            urls.get('upload')))
        self.useFixture(fixtures.EnvironmentVariable(
            'UBUNTU_SSO_API_ROOT_URL',
            urls.get('sso')))
        self.useFixture(fixtures.EnvironmentVariable(
            'UBUNTU_STORE_SEARCH_ROOT_URL',
            urls.get('search')))


class SetTestStore(fixtures.Fixture):
    """Configure the env variables for using the corresponding
    environment urls"""

    def __init__(self):
        self.register_delay = -1

    def setUp(self):
        super().setUp()
        test_store = get_current_store()
        self.useFixture(SetStoreEnvironmentVariables(test_store))
        if test_store == 'staging':
            self.register_delay = 10
        elif test_store == 'production':
            # Use the default server URLs
            self.register_delay = 180
        else:
            raise ValueError(
                'Unknown test store option: {}'.format(test_store))
