# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Snappy Ecosystem Tests
# Copyright (C) 2017 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""Entry point to run snappy ecosystem tests"""

import argparse
import os
import re
import sys
import pytest


def _parse_arguments():
    """Parse and filter command line arguments to makethem pytest compatible"""
    sys.argv[0] = re.sub(r'(-script\.pyw?|\.exe)?$', '', sys.argv[0])
    parser = argparse.ArgumentParser(description=
                                     'Run snappy ecosystem tests.')
    parser.add_argument('--proxy',
                        help='proxy to use for creating the virtual env.',
                        required=False)
    parser.add_argument('--target', default="lxd",
                        help='Target on which tests will be executed.')
    ecosystem_args, pytest_args = parser.parse_known_args()
    _set_env_variables(ecosystem_args)
    return pytest_args


def _set_env_variables(args):
    """
    Set environment variables with ecosystem arguments passed
    in the command line.
    :param args: The arguments to store in env variables
    """
    for arg in vars(args):
        value = getattr(args, arg, None)
        if value:
            os.environ[arg] = value

if __name__ == '__main__':
    sys.exit(pytest.main(args=_parse_arguments() + ['-p', 'no:cacheprovider']))
