# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Snappy Ecosystem Tests
# Copyright (C) 2017 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""Filter utils"""


def object_filter(**predicates):
    """
    Higher-order function to build and return an object filter function
     :param predicates: key/values that represent
     the conditions to look for in the object instance.
    :return: a function to be used with filter or lambda expressions.
    :raise: AttributeError if any of the attributes provided in predicates
     does not exists
    """
    def wrapped_filter(instance):
        """wrapped function to be returned when calling object_filter"""
        return all(getattr(instance,
                           param) == val for param, val in predicates.items())
    return wrapped_filter


def filter_list(objects_list, **predicates):
    """
    Filter a list of objects with the given predicates
    :param objects_list: the target list that contains
     the objects to be filtered
    :param predicates: key/values that represent
    the conditions to look for in the object list.
    :return: A list with the objects that match all the predicates
    :raise: AttributeError if any of the attributes provided in predicates
     does not exists
    """
    return list(filter(object_filter(**predicates), objects_list))
