# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Snappy Ecosystem Tests
# Copyright (C) 2017 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""Utility for printing Store versions of: CPI, SCA and SSO.
To be called as a standalone script.
"""

import requests

DEFAULT_HEADER = "X-BZR-REVISION-NUMBER"

SERVICES_INFO = dict(
    CPI=('https://search.apps.ubuntu.com/api/v1',
         'https://search.apps.staging.ubuntu.com/api/v1'),
    SCA=('https://myapps.developer.ubuntu.com/',
         'https://myapps.developer.staging.ubuntu.com/'),
    SSO=('https://login.ubuntu.com/',
         'https://login.staging.ubuntu.com/'),
)


def get_deployed_revno(service, environment):
    """Get revno from service."""
    prod, stag = SERVICES_INFO[service]
    if environment == 'staging':
        url = stag
    else:
        url = prod
    with requests.Session() as session:
        resp = session.get(url)
        if resp.status_code == 200:
            revno = resp.headers[DEFAULT_HEADER]
        else:
            print("{} 500'ed: {}".format(service, resp.text))
            revno = 0
    return service, environment, revno


def print_versions():
    """Print Store components version"""
    coros = []
    for service in SERVICES_INFO:
        coro = get_deployed_revno(service, 'staging')
        coros.append(coro)
        coro = get_deployed_revno(service, 'production')
        coros.append(coro)

    data = {(service, kind): value for service, kind, value in coros}
    print("#########################-STORE VERSIONS-#########################")
    for service in sorted(SERVICES_INFO):
        print("{}:    Staging:    {:>5}".format(service,
                                                data[(service, 'staging')]))
        print("{}:    Production: {:>5}".format(service,
                                                data[(service, 'production')]))

if __name__ == '__main__':
    print_versions()
