# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Snappy Ecosystem Tests
# Copyright (C) 2017 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""Get all the store related data like credentials, urls"""

import os

from snappy_ecosystem_tests.commons.config import (
    CONFIG_STACK,
    USER_CONFIG_STACK
)

URL_WEB_STORE_PRODUCTION = CONFIG_STACK.get('production_urls', 'web')
URL_WEB_STORE_STAGING = CONFIG_STACK.get('staging_urls', 'web')


def get_store_credentials():
    """Get user store credentials.
    It will retrieve the credentials stored in a user config file,
    if the config is not found,
    then it will return the ones provided in environment variables
    """
    return (USER_CONFIG_STACK.get('user', 'user_email',
                                  default=os.environ.get('user_email')),
            USER_CONFIG_STACK.get('user', 'user_password',
                                  default=os.environ.get('user_password')))


def is_staging():
    """Return False if environment variable PROD is exported"""
    return get_current_store() == 'staging'


def get_store_web_url():
    """This will return Ubuntu Store web url from staging server,
    if optional staging argument is false then it will return
    production server url """
    return URL_WEB_STORE_STAGING if is_staging() else URL_WEB_STORE_PRODUCTION


def get_current_store():
    """
    Return the current configured store. It will first read the config value,
    if no config value is set, it will read the env variable TEST_STORE,
    if that env variable is not set, then it returns staging as default
    :return: current configured store environment
    """
    return CONFIG_STACK.get('store', 'environment',
                            os.getenv('TEST_STORE', 'staging'))
